@@ -24,15 +24,17 @@ class QueryClient(object):
 
     def __init__(self, nameservers=None, query_timeout=None,
                  build_interval=None, build_timeout=None):
-        self.nameservers = nameservers or []
+        self.nameservers = nameservers or CONF.dns.nameservers
         self.query_timeout = query_timeout or CONF.dns.query_timeout
         self.build_interval = build_interval or CONF.dns.build_interval
         self.build_timeout = build_timeout or CONF.dns.build_timeout
-
         self.clients = [SingleQueryClient(ns, query_timeout=query_timeout)
                         for ns in nameservers]
 
     def query(self, zone_name, rdatatype):
+        if not self.nameservers:
+            raise ValueError('Nameservers list cannot be empty and it should '
+                             'contain DNS backend IPs to "dig" for')
         return [c.query(zone_name, rdatatype) for c in self.clients]
 
 
